telephone_check library
Classes
- TelephoneChecker
-
The
TelephoneCheckerclass in Dart provides a static methodisValidto check if a given string matches a specific telephone number pattern.
TelephoneChecker class in Dart provides a static method isValid to check if a given string
matches a specific telephone number pattern.